Documentation
¶
Overview ¶
TODO: Remove this function once Helmfile v0.x
TODO: Remove this function once Helmfile v0.x
Index ¶
- func NewCLIConfigImpl(g *GlobalImpl) error
- type ApplyImpl
- func (a *ApplyImpl) Cascade() string
- func (a *ApplyImpl) Concurrency() int
- func (a *ApplyImpl) Context() int
- func (a *ApplyImpl) DetailedExitcode() bool
- func (a *ApplyImpl) DiffArgs() string
- func (a *ApplyImpl) DiffOutput() string
- func (a *ApplyImpl) IncludeNeeds() bool
- func (a *ApplyImpl) IncludeTests() bool
- func (a *ApplyImpl) IncludeTransitiveNeeds() bool
- func (a *ApplyImpl) NoHooks() bool
- func (a *ApplyImpl) PostRenderer() string
- func (a *ApplyImpl) PostRendererArgs() []string
- func (a *ApplyImpl) ResetValues() bool
- func (a *ApplyImpl) RetainValuesFiles() bool
- func (a *ApplyImpl) ReuseValues() bool
- func (a *ApplyImpl) Set() []string
- func (a *ApplyImpl) ShowSecrets() bool
- func (a *ApplyImpl) SkipCRDs() bool
- func (a *ApplyImpl) SkipCleanup() bool
- func (a *ApplyImpl) SkipDiffOnInstall() bool
- func (a *ApplyImpl) SkipNeeds() bool
- func (a *ApplyImpl) StripTrailingCR() bool
- func (a *ApplyImpl) Suppress() []string
- func (a *ApplyImpl) SuppressDiff() bool
- func (a *ApplyImpl) SuppressOutputLineRegex() []string
- func (a *ApplyImpl) SuppressSecrets() bool
- func (a *ApplyImpl) SyncArgs() string
- func (a *ApplyImpl) Validate() bool
- func (a *ApplyImpl) Values() []string
- func (a *ApplyImpl) Wait() bool
- func (a *ApplyImpl) WaitForJobs() bool
- type ApplyOptions
- type BuildImpl
- type BuildOptions
- type CacheImpl
- type CacheOptions
- type ChartsImpl
- type ChartsOptions
- type DeleteImpl
- type DeleteOptions
- type DepsImpl
- type DepsOptions
- type DestroyImpl
- type DestroyOptions
- type DiffImpl
- func (t *DiffImpl) Concurrency() int
- func (t *DiffImpl) Context() int
- func (t *DiffImpl) DetailedExitcode() bool
- func (t *DiffImpl) DiffArgs() string
- func (t *DiffImpl) DiffOutput() string
- func (t *DiffImpl) IncludeNeeds() bool
- func (t *DiffImpl) IncludeTests() bool
- func (t *DiffImpl) IncludeTransitiveNeeds() bool
- func (t *DiffImpl) NoHooks() bool
- func (t *DiffImpl) PostRenderer() string
- func (t *DiffImpl) PostRendererArgs() []string
- func (t *DiffImpl) ResetValues() bool
- func (t *DiffImpl) ReuseValues() bool
- func (t *DiffImpl) Set() []string
- func (t *DiffImpl) ShowSecrets() bool
- func (t *DiffImpl) SkipCRDs() bool
- func (t *DiffImpl) SkipDiffOnInstall() bool
- func (t *DiffImpl) SkipNeeds() bool
- func (a *DiffImpl) StripTrailingCR() bool
- func (t *DiffImpl) Suppress() []string
- func (t *DiffImpl) SuppressDiff() bool
- func (t *DiffImpl) SuppressOutputLineRegex() []string
- func (t *DiffImpl) SuppressSecrets() bool
- func (t *DiffImpl) Validate() bool
- func (t *DiffImpl) Values() []string
- type DiffOptions
- type FetchImpl
- type FetchOptions
- type GlobalImpl
- func (g *GlobalImpl) Args() string
- func (g *GlobalImpl) Chart() string
- func (g *GlobalImpl) Color() bool
- func (g *GlobalImpl) DisableForceUpdate() bool
- func (g *GlobalImpl) EnableLiveOutput() bool
- func (g *GlobalImpl) Env() string
- func (g *GlobalImpl) FileOrDir() string
- func (g *GlobalImpl) HelmBinary() string
- func (g *GlobalImpl) Interactive() bool
- func (g *GlobalImpl) KubeContext() string
- func (g *GlobalImpl) Kubeconfig() string
- func (g *GlobalImpl) KustomizeBinary() string
- func (g *GlobalImpl) Logger() *zap.SugaredLogger
- func (g *GlobalImpl) Namespace() string
- func (g *GlobalImpl) NoColor() bool
- func (g *GlobalImpl) RawStateValuesSet() []string
- func (g *GlobalImpl) RawStateValuesSetString() []string
- func (g *GlobalImpl) Selectors() []string
- func (g *GlobalImpl) SetSet(set map[string]any)
- func (g *GlobalImpl) SkipDeps() bool
- func (g *GlobalImpl) StateValuesFiles() []string
- func (g *GlobalImpl) StateValuesSet() map[string]any
- func (g *GlobalImpl) StripArgsValuesOnExitError() bool
- func (g *GlobalImpl) ValidateConfig() error
- type GlobalOptions
- type InitImpl
- type InitOptions
- type LintImpl
- type LintOptions
- type ListImpl
- type ListOptions
- type ReposImpl
- type ReposOptions
- type ShowDAGImpl
- type ShowDAGOptions
- type StatusImpl
- type StatusOptions
- type SyncImpl
- func (t *SyncImpl) Cascade() string
- func (t *SyncImpl) Concurrency() int
- func (t *SyncImpl) IncludeNeeds() bool
- func (t *SyncImpl) IncludeTransitiveNeeds() bool
- func (t *SyncImpl) PostRenderer() string
- func (t *SyncImpl) PostRendererArgs() []string
- func (t *SyncImpl) ResetValues() bool
- func (t *SyncImpl) ReuseValues() bool
- func (t *SyncImpl) Set() []string
- func (t *SyncImpl) SkipCRDs() bool
- func (t *SyncImpl) SkipNeeds() bool
- func (t *SyncImpl) SyncArgs() string
- func (t *SyncImpl) Validate() bool
- func (t *SyncImpl) Values() []string
- func (t *SyncImpl) Wait() bool
- func (t *SyncImpl) WaitForJobs() bool
- type SyncOptions
- type TemplateImpl
- func (t *TemplateImpl) Concurrency() int
- func (t *TemplateImpl) IncludeCRDs() bool
- func (t *TemplateImpl) IncludeNeeds() bool
- func (t *TemplateImpl) IncludeTransitiveNeeds() bool
- func (t *TemplateImpl) KubeVersion() string
- func (t *TemplateImpl) OutputDir() string
- func (t *TemplateImpl) OutputDirTemplate() string
- func (t *TemplateImpl) PostRenderer() string
- func (t *TemplateImpl) PostRendererArgs() []string
- func (t *TemplateImpl) Set() []string
- func (t *TemplateImpl) SkipCleanup() bool
- func (t *TemplateImpl) SkipNeeds() bool
- func (t *TemplateImpl) SkipTests() bool
- func (t *TemplateImpl) Validate() bool
- func (t *TemplateImpl) Values() []string
- type TemplateOptions
- type TestImpl
- type TestOptions
- type WriteValuesImpl
- type WriteValuesOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCLIConfigImpl ¶ added in v0.145.3
func NewCLIConfigImpl(g *GlobalImpl) error
Types ¶
type ApplyImpl ¶ added in v0.145.3
type ApplyImpl struct {
*GlobalImpl
*ApplyOptions
}
ApplyImpl is impl for applyOptions
func NewApplyImpl ¶ added in v0.145.3
func NewApplyImpl(g *GlobalImpl, a *ApplyOptions) *ApplyImpl
NewApplyImpl creates a new ApplyImpl
func (*ApplyImpl) Concurrency ¶ added in v0.145.3
Concurrency returns the concurrency.
func (*ApplyImpl) DetailedExitcode ¶ added in v0.145.3
DetailedExitcode returns the detailed exitcode.
func (*ApplyImpl) DiffArgs ¶ added in v0.156.0
DiffArgs is the list of arguments to pass to helm-diff.
func (*ApplyImpl) DiffOutput ¶ added in v0.145.3
DiffOutput returns the diff output.
func (*ApplyImpl) IncludeNeeds ¶ added in v0.145.3
IncludeNeeds returns the include needs.
func (*ApplyImpl) IncludeTests ¶ added in v0.145.3
IncludeTests returns the include tests.
func (*ApplyImpl) IncludeTransitiveNeeds ¶ added in v0.145.3
IncludeTransitiveNeeds returns the include transitive needs.
func (*ApplyImpl) PostRenderer ¶ added in v0.149.0
PostRenderer returns the PostRenderer.
func (*ApplyImpl) PostRendererArgs ¶ added in v0.159.0
PostRendererArgs returns the PostRendererArgs.
func (*ApplyImpl) ResetValues ¶ added in v0.150.0
func (*ApplyImpl) RetainValuesFiles ¶ added in v0.145.3
TODO: Remove this function once Helmfile v0.x RetainValuesFiles returns the retain values files.
func (*ApplyImpl) ReuseValues ¶ added in v0.147.0
ReuseValues returns the ReuseValues.
func (*ApplyImpl) ShowSecrets ¶ added in v0.145.3
ShowSecrets returns the show secrets.
func (*ApplyImpl) SkipCleanup ¶ added in v0.145.3
SkipCleanup returns the skip cleanup.
func (*ApplyImpl) SkipDiffOnInstall ¶ added in v0.145.3
SkipDiffOnInstall returns the skip diff on install.
func (*ApplyImpl) StripTrailingCR ¶ added in v0.154.0
StripTrailingCR is true if trailing carriage returns should be stripped during diffing
func (*ApplyImpl) SuppressDiff ¶ added in v0.145.3
SuppressDiff returns the suppress diff.
func (*ApplyImpl) SuppressOutputLineRegex ¶ added in v0.162.0
SuppressOutputLineRegex returns the SuppressOutputLineRegex.
func (*ApplyImpl) SuppressSecrets ¶ added in v0.145.3
SuppressSecrets returns the suppress secrets.
func (*ApplyImpl) WaitForJobs ¶ added in v0.145.3
WaitForJobs returns the wait for jobs.
type ApplyOptions ¶ added in v0.145.3
type ApplyOptions struct {
// Set is a list of key value pairs to be merged into the command
Set []string
// Values is a list of value files to be merged into the command
Values []string
// Concurrency is the maximum number of concurrent helm processes to run
Concurrency int
// Validate is validate your manifests against the Kubernetes cluster you are currently pointing at. Note that this requires access to a Kubernetes cluster to obtain information necessary for validating, like the list of available API versions
Validate bool
// Context is the number of lines of context to show around changes
Context int
// Output is the output format for the diff plugin
Output string
// DetailedExitcode is true if the exit code should be 2 instead of 0 if there were changes detected and the changes were synced successfully
DetailedExitcode bool
// StripTrailingCR is true if trailing carriage returns should be stripped during diffing
StripTrailingCR bool
// TODO: Remove this function once Helmfile v0.x
// DEPRECATED: Use skip-cleanup instead
RetainValuesFiles bool
// SkipCleanup is true if the cleanup of temporary values files should be skipped
SkipCleanup bool
// SkipCRDs is true if the CRDs should be skipped
SkipCRDs bool
// SkipNeeds is true if the needs should be skipped
SkipNeeds bool
// IncludeNeeds is true if the needs should be included
IncludeNeeds bool
// IncludeTransitiveNeeds is true if the transitive needs should be included
IncludeTransitiveNeeds bool
// SkipDiffOnInstall is true if the diff should be skipped on install
SkipDiffOnInstall bool
// DiffArgs is the list of arguments to pass to the helm-diff.
DiffArgs string
// IncludeTests is true if the tests should be included
IncludeTests bool
// Suppress is true if the output should be suppressed
Suppress []string
// SuppressSecrets is true if the secrets should be suppressed
SuppressSecrets bool
// ShowSecrets is true if the secrets should be shown
ShowSecrets bool
// NoHooks skips checking for hooks
NoHooks bool
// SuppressDiff is true if the diff should be suppressed
SuppressDiff bool
// Wait is true if the helm command should wait for the release to be deployed
Wait bool
// WaitForJobs is true if the helm command should wait for the jobs to be completed
WaitForJobs bool
// ReuseValues is true if the helm command should reuse the values
ReuseValues bool
// ResetValues is true if helm command should reset values to charts' default
ResetValues bool
// Propagate '--post-renderer' to helmv3 template and helm install
PostRenderer string
// Propagate '--post-renderer-args' to helmv3 template and helm install
PostRendererArgs []string
// Cascade '--cascade' to helmv3 delete, available values: background, foreground, or orphan, default: background
Cascade string
// SuppressOutputLineRegex is a list of regexes to suppress output lines
SuppressOutputLineRegex []string
// SyncArgs is the list of arguments to pass to helm upgrade.
SyncArgs string
}
ApplyOptoons is the options for the apply command
func NewApplyOptions ¶ added in v0.145.3
func NewApplyOptions() *ApplyOptions
NewApply creates a new Apply
type BuildImpl ¶ added in v0.145.3
type BuildImpl struct {
*GlobalImpl
*BuildOptions
}
BuildImpl is impl for applyOptions
func NewBuildImpl ¶ added in v0.145.3
func NewBuildImpl(g *GlobalImpl, b *BuildOptions) *BuildImpl
NewBuildImpl creates a new BuildImpl
func (*BuildImpl) EmbedValues ¶ added in v0.145.3
EmbedValues returns the embed values.
type BuildOptions ¶ added in v0.145.3
type BuildOptions struct {
// EmbedValues is true if the values should be embedded
EmbedValues bool
}
BuildOptions is the options for the build command
func NewBuildOptions ¶ added in v0.145.3
func NewBuildOptions() *BuildOptions
NewBuildOptions creates a new Apply
type CacheImpl ¶ added in v0.145.3
type CacheImpl struct {
*GlobalImpl
*CacheOptions
}
CacheImpl is impl for applyOptions
func NewCacheImpl ¶ added in v0.145.3
func NewCacheImpl(g *GlobalImpl, b *CacheOptions) *CacheImpl
NewCacheImpl creates a new CacheImpl
type CacheOptions ¶ added in v0.145.3
type CacheOptions struct{}
CacheOptions is the options for the build command
func NewCacheOptions ¶ added in v0.145.3
func NewCacheOptions() *CacheOptions
NewCacheOptions creates a new Apply
type ChartsImpl ¶ added in v0.145.3
type ChartsImpl struct {
*GlobalImpl
*ChartsOptions
}
ChartsImpl is impl for applyOptions
func NewChartsImpl ¶ added in v0.145.3
func NewChartsImpl(g *GlobalImpl, b *ChartsOptions) *ChartsImpl
NewChartsImpl creates a new ChartsImpl
func (*ChartsImpl) Concurrency ¶ added in v0.145.3
func (c *ChartsImpl) Concurrency() int
Concurrency returns the concurrency
func (*ChartsImpl) IncludeTransitiveNeeds ¶ added in v0.145.3
func (c *ChartsImpl) IncludeTransitiveNeeds() bool
IncludeTransitiveNeeds returns the includeTransitiveNeeds
func (*ChartsImpl) Values ¶ added in v0.145.3
func (c *ChartsImpl) Values() []string
Values returns the values
type ChartsOptions ¶ added in v0.145.3
type ChartsOptions struct {
// Set is the additional values to be merged into the helm command --set flag
Set []string
// Values is the additional value files to be merged into the helm command --values flag
Values []string
// Concurrency is the maximum number of concurrent helm processes to run, 0 is unlimited
Concurrency int
}
ChartsOptions is the options for the build command
func NewChartsOptions ¶ added in v0.145.3
func NewChartsOptions() *ChartsOptions
NewChartsOptions creates a new Apply
type DeleteImpl ¶ added in v0.145.3
type DeleteImpl struct {
*GlobalImpl
*DeleteOptions
}
DeleteImpl is impl for applyOptions
func NewDeleteImpl ¶ added in v0.145.3
func NewDeleteImpl(g *GlobalImpl, b *DeleteOptions) *DeleteImpl
NewDeleteImpl creates a new DeleteImpl
func (*DeleteImpl) Cascade ¶ added in v0.154.0
func (c *DeleteImpl) Cascade() string
Cascade returns cascade flag
func (*DeleteImpl) Concurrency ¶ added in v0.145.3
func (c *DeleteImpl) Concurrency() int
Concurrency returns the concurrency
func (*DeleteImpl) DeleteTimeout ¶ added in v0.160.0
func (c *DeleteImpl) DeleteTimeout() int
DeleteTimeout returns the timeout flag
func (*DeleteImpl) DeleteWait ¶ added in v0.160.0
func (c *DeleteImpl) DeleteWait() bool
DeleteWait returns the wait flag
func (*DeleteImpl) Purge ¶ added in v0.145.3
func (c *DeleteImpl) Purge() bool
Purge returns the purge
func (*DeleteImpl) SkipCharts ¶ added in v0.151.0
func (c *DeleteImpl) SkipCharts() bool
SkipCharts returns skipCharts flag
type DeleteOptions ¶ added in v0.145.3
type DeleteOptions struct {
// Concurrency is the maximum number of concurrent helm processes to run, 0 is unlimited
Concurrency int
// Purge is the purge flag
Purge bool
// SkipCharts makes Delete skip `withPreparedCharts`
SkipCharts bool
// Cascade '--cascade' to helmv3 delete, available values: background, foreground, or orphan, default: background
Cascade string
// Wait '--wait' if set, will wait until all the resources are deleted before returning. It will wait for as long as --timeout
DeleteWait bool
// Timeout '--timeout', to wait for helm delete operation (default 5m0s)
DeleteTimeout int
}
DeleteOptions is the options for the build command
func NewDeleteOptions ¶ added in v0.145.3
func NewDeleteOptions() *DeleteOptions
NewDeleteOptions creates a new Apply
type DepsImpl ¶ added in v0.145.3
type DepsImpl struct {
*GlobalImpl
*DepsOptions
}
DepsImpl is impl for applyOptions
func NewDepsImpl ¶ added in v0.145.3
func NewDepsImpl(g *GlobalImpl, b *DepsOptions) *DepsImpl
NewDepsImpl creates a new DepsImpl
func (*DepsImpl) Concurrency ¶ added in v0.145.5
Concurrency returns the concurrency
func (*DepsImpl) IncludeTransitiveNeeds ¶ added in v0.145.3
IncludeTransitiveNeeds returns the includeTransitiveNeeds
type DepsOptions ¶ added in v0.145.3
type DepsOptions struct {
// SkipRepos is the skip repos flag
SkipRepos bool
// Concurrency is the maximum number of concurrent helm processes to run
Concurrency int
}
DepsOptions is the options for the build command
func NewDepsOptions ¶ added in v0.145.3
func NewDepsOptions() *DepsOptions
NewDepsOptions creates a new Apply
type DestroyImpl ¶ added in v0.145.3
type DestroyImpl struct {
*GlobalImpl
*DestroyOptions
}
DestroyImpl is impl for applyOptions
func NewDestroyImpl ¶ added in v0.145.3
func NewDestroyImpl(g *GlobalImpl, b *DestroyOptions) *DestroyImpl
NewDestroyImpl creates a new DestroyImpl
func (*DestroyImpl) Cascade ¶ added in v0.154.0
func (c *DestroyImpl) Cascade() string
Cascade returns cascade flag
func (*DestroyImpl) Concurrency ¶ added in v0.145.3
func (c *DestroyImpl) Concurrency() int
Concurrency returns the concurrency
func (*DestroyImpl) DeleteTimeout ¶ added in v0.160.0
func (c *DestroyImpl) DeleteTimeout() int
DeleteTimeout returns the timeout flag
func (*DestroyImpl) DeleteWait ¶ added in v0.160.0
func (c *DestroyImpl) DeleteWait() bool
DeleteWait returns the wait flag
func (*DestroyImpl) SkipCharts ¶ added in v0.151.0
func (c *DestroyImpl) SkipCharts() bool
SkipCharts returns skipCharts flag
type DestroyOptions ¶ added in v0.145.3
type DestroyOptions struct {
// Concurrency is the maximum number of concurrent helm processes to run, 0 is unlimited
Concurrency int
// SkipCharts makes Destroy skip `withPreparedCharts`
SkipCharts bool
// Cascade '--cascade' to helmv3 delete, available values: background, foreground, or orphan, default: background
Cascade string
// Wait '--wait' if set, will wait until all the resources are destroyed before returning. It will wait for as long as --timeout
DeleteWait bool
// Timeout '--timeout', to wait for helm operation (default 5m0s)
DeleteTimeout int
}
DestroyOptions is the options for the build command
func NewDestroyOptions ¶ added in v0.145.3
func NewDestroyOptions() *DestroyOptions
NewDestroyOptions creates a new Apply
type DiffImpl ¶ added in v0.145.3
type DiffImpl struct {
*GlobalImpl
*DiffOptions
}
DiffImpl is impl for applyOptions
func NewDiffImpl ¶ added in v0.145.3
func NewDiffImpl(g *GlobalImpl, t *DiffOptions) *DiffImpl
NewDiffImpl creates a new DiffImpl
func (*DiffImpl) Concurrency ¶ added in v0.145.3
Concurrency returns the concurrency
func (*DiffImpl) DetailedExitcode ¶ added in v0.145.3
DetailedExitCode returns the detailed exit code
func (*DiffImpl) DiffArgs ¶ added in v0.156.0
DiffArgs returns the list of arguments to pass to helm-diff.
func (*DiffImpl) DiffOutput ¶ added in v0.145.3
Output returns the output
func (*DiffImpl) IncludeNeeds ¶ added in v0.145.3
IncludeNeeds returns the include needs
func (*DiffImpl) IncludeTests ¶ added in v0.145.3
IncludeTests returns the include tests
func (*DiffImpl) IncludeTransitiveNeeds ¶ added in v0.145.3
IncludeTransitiveNeeds returns the include transitive needs
func (*DiffImpl) PostRenderer ¶ added in v0.151.0
PostRenderer returns the PostRenderer.
func (*DiffImpl) PostRendererArgs ¶ added in v0.159.0
PostRendererArgs returns the PostRendererArgs.
func (*DiffImpl) ResetValues ¶ added in v0.150.0
func (*DiffImpl) ReuseValues ¶ added in v0.147.0
ReuseValues returns the ReuseValues.
func (*DiffImpl) ShowSecrets ¶ added in v0.145.3
ShowSecrets returns the show secrets
func (*DiffImpl) SkipDiffOnInstall ¶ added in v0.145.3
SkipDiffOnInstall returns the skip diff on install
func (*DiffImpl) StripTrailingCR ¶ added in v0.154.0
StripTrailingCR is true if trailing carriage returns should be stripped during diffing
func (*DiffImpl) SuppressDiff ¶ added in v0.145.3
SuppressDiff returns the suppress diff
func (*DiffImpl) SuppressOutputLineRegex ¶ added in v0.162.0
SuppressOutputLineRegex returns the SuppressOutputLineRegex.
func (*DiffImpl) SuppressSecrets ¶ added in v0.145.3
SuppressSecrets returns the suppress secrets
type DiffOptions ¶ added in v0.145.3
type DiffOptions struct {
// Set is the set flag
Set []string
// Values is the values flag
Values []string
// DetailedExitcode is the detailed exit code
DetailedExitcode bool
// StripTrailingCR is true if trailing carriage returns should be stripped during diffing
StripTrailingCR bool
// IncludeTests is the include tests flag
IncludeTests bool
// SkipNeeds is the include crds flag
SkipNeeds bool
// IncludeNeeds is the include needs flag
IncludeNeeds bool
// IncludeTransitiveNeeds is the include transitive needs flag
IncludeTransitiveNeeds bool
// SkipDiffOnInstall is the skip diff on install flag
SkipDiffOnInstall bool
// ShowSecrets is the show secrets flag
ShowSecrets bool
// NoHooks skips hooks during diff
NoHooks bool
// Suppress is the suppress flag
Suppress []string
// SuppressSecrets is the suppress secrets flag
SuppressSecrets bool
// Concurrency is the concurrency flag
Concurrency int
// Validate is the validate flag
Validate bool
// Context is the context flag
Context int
// Output is output flag
Output string
// ReuseValues is true if the helm command should reuse the values
ReuseValues bool
// ResetValues is true if helm command should reset values to charts' default
ResetValues bool
// Propagate '--post-renderer' to helmv3 template and helm install
PostRenderer string
// Propagate '--post-renderer-args' to helmv3 template and helm install
PostRendererArgs []string
// DiffArgs is the list of arguments to pass to helm-diff.
DiffArgs string
// SuppressOutputLineRegex is a list of regexes to suppress output lines
SuppressOutputLineRegex []string
}
DiffOptions is the options for the build command
func NewDiffOptions ¶ added in v0.145.3
func NewDiffOptions() *DiffOptions
NewDiffOptions creates a new Apply
type FetchImpl ¶ added in v0.145.3
type FetchImpl struct {
*GlobalImpl
*FetchOptions
}
FetchImpl is impl for applyOptions
func NewFetchImpl ¶ added in v0.145.3
func NewFetchImpl(g *GlobalImpl, b *FetchOptions) *FetchImpl
NewFetchImpl creates a new FetchImpl
func (*FetchImpl) Concurrency ¶ added in v0.145.3
Concurrency returns the concurrency
func (*FetchImpl) OutputDirTemplate ¶ added in v0.148.0
OutputDirTemplate returns the go template to generate the path of output directory
type FetchOptions ¶ added in v0.145.3
type FetchOptions struct {
// Concurrency is the maximum number of concurrent helm processes to run, 0 is unlimited
Concurrency int
// OutputDir is the output directory
OutputDir string
// OutputDirTemplate is the go template to generate the path of output directory
OutputDirTemplate string
}
FetchOptions is the options for the build command
func NewFetchOptions ¶ added in v0.145.3
func NewFetchOptions() *FetchOptions
NewFetchOptions creates a new Apply
type GlobalImpl ¶ added in v0.145.3
type GlobalImpl struct {
*GlobalOptions
// contains filtered or unexported fields
}
GlobalImpl is the global configuration for the Helmfile CLI.
func NewGlobalImpl ¶ added in v0.145.3
func NewGlobalImpl(opts *GlobalOptions) *GlobalImpl
NewGlobalImpl creates a new GlobalImpl.
func (*GlobalImpl) Args ¶ added in v0.148.0
func (g *GlobalImpl) Args() string
Args returns the args to use for helm
func (*GlobalImpl) Chart ¶ added in v0.145.3
func (g *GlobalImpl) Chart() string
Chart returns the chart to use.
func (*GlobalImpl) Color ¶ added in v0.145.3
func (g *GlobalImpl) Color() bool
func (*GlobalImpl) DisableForceUpdate ¶ added in v0.153.0
func (g *GlobalImpl) DisableForceUpdate() bool
DisableForceUpdate return when to disable forcing updates to repos upon adding
func (*GlobalImpl) EnableLiveOutput ¶ added in v0.146.0
func (g *GlobalImpl) EnableLiveOutput() bool
EnableLiveOutput return when to pipe the stdout and stderr from Helm live to the helmfile stdout
func (*GlobalImpl) Env ¶ added in v0.145.3
func (g *GlobalImpl) Env() string
Env returns the environment to use.
func (*GlobalImpl) FileOrDir ¶ added in v0.145.3
func (g *GlobalImpl) FileOrDir() string
FileOrDir returns the path to the Helmfile.
func (*GlobalImpl) HelmBinary ¶ added in v0.145.3
func (g *GlobalImpl) HelmBinary() string
HelmBinary returns the path to the Helm binary.
func (*GlobalImpl) Interactive ¶ added in v0.145.3
func (g *GlobalImpl) Interactive() bool
Interactive returns the Interactive
func (*GlobalImpl) KubeContext ¶ added in v0.145.3
func (g *GlobalImpl) KubeContext() string
KubeContext returns the name of the kubectl context to use.
func (*GlobalImpl) Kubeconfig ¶ added in v0.163.0
func (g *GlobalImpl) Kubeconfig() string
Kubeconfig returns the path to the kubeconfig file to use.
func (*GlobalImpl) KustomizeBinary ¶ added in v0.158.0
func (g *GlobalImpl) KustomizeBinary() string
KustomizeBinary returns the path to the Kustomize binary.
func (*GlobalImpl) Logger ¶ added in v0.145.3
func (g *GlobalImpl) Logger() *zap.SugaredLogger
Logger returns the logger
func (*GlobalImpl) Namespace ¶ added in v0.145.3
func (g *GlobalImpl) Namespace() string
Namespace returns the namespace to use.
func (*GlobalImpl) NoColor ¶ added in v0.145.3
func (g *GlobalImpl) NoColor() bool
NoColor returns the no color flag
func (*GlobalImpl) RawStateValuesSet ¶ added in v0.145.3
func (g *GlobalImpl) RawStateValuesSet() []string
StateValuesSet returns the set
func (*GlobalImpl) RawStateValuesSetString ¶ added in v0.160.0
func (g *GlobalImpl) RawStateValuesSetString() []string
RawStateValuesSetString returns the set
func (*GlobalImpl) Selectors ¶ added in v0.145.3
func (g *GlobalImpl) Selectors() []string
Selectors returns the selectors to use.
func (*GlobalImpl) SetSet ¶ added in v0.145.3
func (g *GlobalImpl) SetSet(set map[string]any)
Setset sets the set
func (*GlobalImpl) SkipDeps ¶ added in v0.153.0
func (g *GlobalImpl) SkipDeps() bool
SkipDeps return if running "helm repo update" and "helm dependency build" should be skipped
func (*GlobalImpl) StateValuesFiles ¶ added in v0.145.3
func (g *GlobalImpl) StateValuesFiles() []string
StateValuesFiles returns the state values files
func (*GlobalImpl) StateValuesSet ¶ added in v0.145.3
func (g *GlobalImpl) StateValuesSet() map[string]any
StateValuesSet returns the set
func (*GlobalImpl) StripArgsValuesOnExitError ¶ added in v0.155.0
func (g *GlobalImpl) StripArgsValuesOnExitError() bool
StripArgsValuesOnExitError return if the ARGS output on exit error should be suppressed
func (*GlobalImpl) ValidateConfig ¶ added in v0.145.3
func (g *GlobalImpl) ValidateConfig() error
ValidateConfig validates the global options.
type GlobalOptions ¶ added in v0.145.3
type GlobalOptions struct {
// HelmBinary is the path to the Helm binary.
HelmBinary string
// KustomizeBinary is the path to the Kustomize binary.
KustomizeBinary string
// File is the path to the Helmfile.
File string
// Environment is the name of the environment to use.
Environment string
// StateValuesSet is a list of state values to set on the command line.
StateValuesSet []string
// StateValuesSetString is a list of state values to set on the command line.
StateValuesSetString []string
// StateValuesFiles is a list of state values files to use.
StateValuesFile []string
// SkipDeps is true if the running "helm repo update" and "helm dependency build" should be skipped
SkipDeps bool
// StripArgsValuesOnExitError is true if the ARGS output on exit error should be suppressed
StripArgsValuesOnExitError bool
// DisableForceUpdate is true if force updating repos is not desirable when executing "helm repo add"
DisableForceUpdate bool
// Quiet is true if the output should be quiet.
Quiet bool
// Kubeconfig is the path to the kubeconfig file to use.
Kubeconfig string
// KubeContext is the name of the kubectl context to use.
KubeContext string
// Debug is true if the output should be verbose.
Debug bool
// Color is true if the output should be colorized.
Color bool
// NoColor is true if the output should not be colorized.
NoColor bool
// LogLevel is the log level to use.
LogLevel string
// Namespace is the namespace to use.
Namespace string
// Chart is the chart to use.
Chart string
// Selector is a list of selectors to use.
Selector []string
// AllowNoMatchingRelease is not exit with an error code if the provided selector has no matching releases.
AllowNoMatchingRelease bool
// EnableLiveOutput enables live output from the Helm binary stdout/stderr into Helmfile own stdout/stderr
EnableLiveOutput bool
// Interactive is true if the user should be prompted for input.
Interactive bool
// Args is the list of arguments to pass to the Helm binary.
Args string
// contains filtered or unexported fields
}
GlobalOptions is the global configuration for the Helmfile CLI.
func (*GlobalOptions) Logger ¶ added in v0.145.3
func (g *GlobalOptions) Logger() *zap.SugaredLogger
Logger returns the logger to use.
func (*GlobalOptions) SetLogger ¶ added in v0.145.3
func (g *GlobalOptions) SetLogger(logger *zap.SugaredLogger)
GetLogLevel returns the log level to use.
type InitImpl ¶ added in v0.148.0
type InitImpl struct {
*GlobalImpl
*InitOptions
}
InitImpl is impl for InitOptions
func NewInitImpl ¶ added in v0.148.0
func NewInitImpl(g *GlobalImpl, b *InitOptions) *InitImpl
NewInitImpl creates a new InitImpl
type InitOptions ¶ added in v0.148.0
type InitOptions struct {
Force bool
}
InitOptions is the options for the init command
func NewInitOptions ¶ added in v0.148.0
func NewInitOptions() *InitOptions
NewInitOptions creates a new InitOptions
type LintImpl ¶ added in v0.145.3
type LintImpl struct {
*GlobalImpl
*LintOptions
}
LintImpl is impl for applyOptions
func NewLintImpl ¶ added in v0.145.3
func NewLintImpl(g *GlobalImpl, b *LintOptions) *LintImpl
NewLintImpl creates a new LintImpl
func (*LintImpl) Concurrency ¶ added in v0.145.3
Concurrency returns the concurrency
func (*LintImpl) IncludeNeeds ¶ added in v0.145.3
IncludeNeeds returns the include needs
func (*LintImpl) IncludeTransitiveNeeds ¶ added in v0.145.3
IncludeTransitiveNeeds returns the include transitive needs
func (*LintImpl) SkipCleanup ¶ added in v0.145.3
SkipCleanUp returns the skip clean up
type LintOptions ¶ added in v0.145.3
type LintOptions struct {
// Concurrency is the maximum number of concurrent helm processes to run, 0 is unlimited
Concurrency int
// Set is the set flags to pass to helm lint
Set []string
// Values is the values flags to pass to helm lint
Values []string
// SkipNeeds is the skip needs flag
SkipNeeds bool
// IncludeNeeds is the include needs flag
IncludeNeeds bool
// IncludeTransitiveNeeds is the include transitive needs flag
IncludeTransitiveNeeds bool
}
LintOptions is the options for the build command
func NewLintOptions ¶ added in v0.145.3
func NewLintOptions() *LintOptions
NewLintOptions creates a new Apply
type ListImpl ¶ added in v0.145.3
type ListImpl struct {
*GlobalImpl
*ListOptions
}
ListImpl is impl for applyOptions
func NewListImpl ¶ added in v0.145.3
func NewListImpl(g *GlobalImpl, b *ListOptions) *ListImpl
NewListImpl creates a new ListImpl
func (*ListImpl) SkipCharts ¶ added in v0.145.5
SkipCharts returns skipCharts flag
type ListOptions ¶ added in v0.145.3
type ListOptions struct {
// Output is the output format
Output string
// KeepTempDir is the keep temp dir flag
KeepTempDir bool
// SkipCharts makes List skip `withPreparedCharts`
SkipCharts bool
}
ListOptions is the options for the build command
func NewListOptions ¶ added in v0.145.3
func NewListOptions() *ListOptions
NewListOptions creates a new Apply
type ReposImpl ¶ added in v0.145.3
type ReposImpl struct {
*GlobalImpl
*ReposOptions
}
ReposImpl is impl for applyOptions
func NewReposImpl ¶ added in v0.145.3
func NewReposImpl(g *GlobalImpl, b *ReposOptions) *ReposImpl
NewReposImpl creates a new ReposImpl
func (*ReposImpl) IncludeTransitiveNeeds ¶ added in v0.145.3
IncludeTransitiveNeeds returns the include transitive needs
type ReposOptions ¶ added in v0.145.3
type ReposOptions struct{}
ReposOptions is the options for the build command
func NewReposOptions ¶ added in v0.145.3
func NewReposOptions() *ReposOptions
NewReposOptions creates a new Apply
type ShowDAGImpl ¶ added in v0.164.0
type ShowDAGImpl struct {
*GlobalImpl
*ShowDAGOptions
}
ShowDAGImpl is impl for applyOptions
func NewShowDAGImpl ¶ added in v0.164.0
func NewShowDAGImpl(g *GlobalImpl, b *ShowDAGOptions) *ShowDAGImpl
NewShowDAGImpl creates a new ShowDAGImpl
type ShowDAGOptions ¶ added in v0.164.0
type ShowDAGOptions struct {
}
ShowDAGOptions is the options for the build command
func NewShowDAGOptions ¶ added in v0.164.0
func NewShowDAGOptions() *ShowDAGOptions
NewShowDAGOptions creates a new ShowDAGOptions
type StatusImpl ¶ added in v0.145.3
type StatusImpl struct {
*GlobalImpl
*StatusOptions
}
StatusImpl is impl for applyOptions
func NewStatusImpl ¶ added in v0.145.3
func NewStatusImpl(g *GlobalImpl, b *StatusOptions) *StatusImpl
NewStatusImpl creates a new StatusImpl
func (*StatusImpl) Concurrency ¶ added in v0.145.3
func (s *StatusImpl) Concurrency() int
Concurrency returns the concurrency
func (*StatusImpl) IncludeTransitiveNeeds ¶ added in v0.145.3
func (s *StatusImpl) IncludeTransitiveNeeds() bool
IncludeTransitiveNeeds returns the include transitive needs
type StatusOptions ¶ added in v0.145.3
type StatusOptions struct {
// Concurrency is the concurrent flag
Concurrency int
}
StatusOptions is the options for the build command
func NewStatusOptions ¶ added in v0.145.3
func NewStatusOptions() *StatusOptions
NewStatusOptions creates a new Apply
type SyncImpl ¶ added in v0.145.3
type SyncImpl struct {
*GlobalImpl
*SyncOptions
}
SyncImpl is impl for applyOptions
func NewSyncImpl ¶ added in v0.145.3
func NewSyncImpl(g *GlobalImpl, t *SyncOptions) *SyncImpl
NewSyncImpl creates a new SyncImpl
func (*SyncImpl) Concurrency ¶ added in v0.145.3
Concurrency returns the concurrency
func (*SyncImpl) IncludeNeeds ¶ added in v0.145.3
IncludeNeeds returns the include needs
func (*SyncImpl) IncludeTransitiveNeeds ¶ added in v0.145.3
IncludeTransitiveNeeds returns the include transitive needs
func (*SyncImpl) PostRenderer ¶ added in v0.149.0
PostRenderer returns the PostRenderer.
func (*SyncImpl) PostRendererArgs ¶ added in v0.159.0
PostRendererArgs returns the PostRendererArgs.
func (*SyncImpl) ResetValues ¶ added in v0.150.0
func (*SyncImpl) ReuseValues ¶ added in v0.147.0
ReuseValues returns the ReuseValues.
func (*SyncImpl) WaitForJobs ¶ added in v0.145.3
WaitForJobs returns the wait for jobs
type SyncOptions ¶ added in v0.145.3
type SyncOptions struct {
// Set is the set flag
Set []string
// Values is the values flag
Values []string
// Concurrency is the concurrency flag
Concurrency int
// Validate is the validate flag
Validate bool
// IncludeCRDs is the include crds flag
SkipNeeds bool
// IncludeNeeds is the include needs flag
IncludeNeeds bool
// IncludeTransitiveNeeds is the include transitive needs flag
IncludeTransitiveNeeds bool
// SkipCrds is the skip crds flag
SkipCRDs bool
// Wait is the wait flag
Wait bool
// WaitForJobs is the wait for jobs flag
WaitForJobs bool
// ReuseValues is true if the helm command should reuse the values
ReuseValues bool
// ResetValues is true if helm command should reset values to charts' default
ResetValues bool
// Propagate '--post-renderer' to helmv3 template and helm install
PostRenderer string
// Propagate '--post-renderer-args' to helmv3 template and helm install
PostRendererArgs []string
// Cascade '--cascade' to helmv3 delete, available values: background, foreground, or orphan, default: background
Cascade string
// SyncArgs is the list of arguments to pass to the helm upgrade command.
SyncArgs string
}
SyncOptions is the options for the build command
func NewSyncOptions ¶ added in v0.145.3
func NewSyncOptions() *SyncOptions
NewSyncOptions creates a new Apply
type TemplateImpl ¶ added in v0.145.3
type TemplateImpl struct {
*GlobalImpl
*TemplateOptions
}
TemplateImpl is impl for applyOptions
func NewTemplateImpl ¶ added in v0.145.3
func NewTemplateImpl(g *GlobalImpl, t *TemplateOptions) *TemplateImpl
NewTemplateImpl creates a new TemplateImpl
func (*TemplateImpl) Concurrency ¶ added in v0.145.3
func (t *TemplateImpl) Concurrency() int
Concurrency returns the concurrency
func (*TemplateImpl) IncludeCRDs ¶ added in v0.145.3
func (t *TemplateImpl) IncludeCRDs() bool
IncludeCRDs returns the include crds
func (*TemplateImpl) IncludeNeeds ¶ added in v0.145.3
func (t *TemplateImpl) IncludeNeeds() bool
IncludeNeeds returns the include needs
func (*TemplateImpl) IncludeTransitiveNeeds ¶ added in v0.145.3
func (t *TemplateImpl) IncludeTransitiveNeeds() bool
IncludeTransitiveNeeds returns the include transitive needs
func (*TemplateImpl) KubeVersion ¶ added in v0.153.0
func (t *TemplateImpl) KubeVersion() string
KubeVersion returns the the KubeVersion.
func (*TemplateImpl) OutputDir ¶ added in v0.145.3
func (t *TemplateImpl) OutputDir() string
OutputDir returns the output dir
func (*TemplateImpl) OutputDirTemplate ¶ added in v0.145.3
func (t *TemplateImpl) OutputDirTemplate() string
OutputDirTemplate returns the output dir template
func (*TemplateImpl) PostRenderer ¶ added in v0.149.0
func (t *TemplateImpl) PostRenderer() string
PostRenderer returns the PostRenderer.
func (*TemplateImpl) PostRendererArgs ¶ added in v0.159.0
func (t *TemplateImpl) PostRendererArgs() []string
PostRendererArgs returns the PostRendererArgs.
func (*TemplateImpl) Set ¶ added in v0.145.3
func (t *TemplateImpl) Set() []string
Set returns the Set
func (*TemplateImpl) SkipCleanup ¶ added in v0.145.3
func (t *TemplateImpl) SkipCleanup() bool
SkipCleanup returns the skip cleanup
func (*TemplateImpl) SkipNeeds ¶ added in v0.145.3
func (t *TemplateImpl) SkipNeeds() bool
SkipNeeds returns the skip needs
func (*TemplateImpl) SkipTests ¶ added in v0.145.3
func (t *TemplateImpl) SkipTests() bool
SkipTests returns the skip tests
func (*TemplateImpl) Validate ¶ added in v0.145.3
func (t *TemplateImpl) Validate() bool
Validate returns the validate
func (*TemplateImpl) Values ¶ added in v0.145.3
func (t *TemplateImpl) Values() []string
Values returns the values
type TemplateOptions ¶ added in v0.145.3
type TemplateOptions struct {
// Set is the set flag
Set []string
// Values is the values flag
Values []string
// OutputDir is the output dir flag
OutputDir string
// OutputDirTemplate is the output dir template flag
OutputDirTemplate string
// Concurrency is the concurrency flag
Concurrency int
// Validate is the validate flag
Validate bool
// IncludeCRDs is the include crds flag
IncludeCRDs bool
// SkipTests is the skip tests flag
SkipTests bool
// SkipNeeds is the skip needs flag
SkipNeeds bool
// IncludeNeeds is the include needs flag
IncludeNeeds bool
// IncludeTransitiveNeeds is the include transitive needs flag
IncludeTransitiveNeeds bool
// SkipCleanup is the skip cleanup flag
SkipCleanup bool
// Propagate '--post-renderer' to helmv3 template and helm install
PostRenderer string
// Propagate '--post-renderer-args' to helmv3 template and helm install
PostRendererArgs []string
// KubeVersion is the kube-version flag
KubeVersion string
}
TemplateOptions is the options for the build command
func NewTemplateOptions ¶ added in v0.145.3
func NewTemplateOptions() *TemplateOptions
NewTemplateOptions creates a new Apply
type TestImpl ¶ added in v0.145.3
type TestImpl struct {
*GlobalImpl
*TestOptions
Cmd *cobra.Command
}
TestImpl is impl for applyOptions
func NewTestImpl ¶ added in v0.145.3
func NewTestImpl(g *GlobalImpl, t *TestOptions) *TestImpl
NewTestImpl creates a new TestImpl
func (*TestImpl) Concurrency ¶ added in v0.145.3
Concurrency returns the concurrency
type TestOptions ¶ added in v0.145.3
type TestOptions struct {
// Concurrency is the maximum number of concurrent helm processes to run, 0 is unlimited
Concurrency int
// Cleanup is the cleanup flag
Cleanup bool
// Logs is the logs flagj
Logs bool
// Timeout is the timeout flag
Timeout int
}
TestOptions is the options for the build command
func NewTestOptions ¶ added in v0.145.3
func NewTestOptions() *TestOptions
NewTestOptions creates a new Apply
type WriteValuesImpl ¶ added in v0.145.3
type WriteValuesImpl struct {
*GlobalImpl
*WriteValuesOptions
}
WriteValuesImpl is impl for applyOptions
func NewWriteValuesImpl ¶ added in v0.145.3
func NewWriteValuesImpl(g *GlobalImpl, b *WriteValuesOptions) *WriteValuesImpl
NewWriteValuesImpl creates a new WriteValuesImpl
func (*WriteValuesImpl) Concurrency ¶ added in v0.145.3
func (c *WriteValuesImpl) Concurrency() int
Concurrency returns the concurrency
func (*WriteValuesImpl) IncludeTransitiveNeeds ¶ added in v0.145.3
func (c *WriteValuesImpl) IncludeTransitiveNeeds() bool
IncludeTransitiveNeeds returns the include transitive needs
func (*WriteValuesImpl) OutputFileTemplate ¶ added in v0.145.3
func (c *WriteValuesImpl) OutputFileTemplate() string
OutputFileTemplate returns the output file template
func (*WriteValuesImpl) Set ¶ added in v0.145.3
func (c *WriteValuesImpl) Set() []string
Set returns the Set
func (*WriteValuesImpl) SkipCleanup ¶ added in v0.145.3
func (c *WriteValuesImpl) SkipCleanup() bool
SkipCleanUp returns the skip clean up
func (*WriteValuesImpl) Values ¶ added in v0.145.3
func (c *WriteValuesImpl) Values() []string
Values returns the Values
type WriteValuesOptions ¶ added in v0.145.3
type WriteValuesOptions struct {
// Concurrency is the maximum number of concurrent helm processes to run, 0 is unlimited
Concurrency int
// Set is the set flags to pass to helm write values
Set []string
// Values is the values flags to pass to helm write values
Values []string
// OutputFileTemplate is the output file template
OutputFileTemplate string
}
WriteValuesOptions is the options for the build command
func NewWriteValuesOptions ¶ added in v0.145.3
func NewWriteValuesOptions() *WriteValuesOptions
NewWriteValuesOptions creates a new Apply