exectest

package
v1.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 3, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsHelm4Enabled added in v1.2.0

func IsHelm4Enabled() bool

IsHelm4Enabled detects the installed Helm version by executing the helm binary. It returns true if Helm 4.x is installed, false for Helm 3.x or earlier. Falls back to environment variable HELMFILE_HELM4 if helm binary is not available.

Types

type Affected

type Affected struct {
	Upgraded    []*Release
	Reinstalled []*Release
	Deleted     []*Release
	Failed      []*Release
}

type DiffKey

type DiffKey struct {
	Name  string
	Chart string
	Flags string
}

type Helm

type Helm struct {
	Charts               []string
	Repo                 []string
	RegistryLoginHost    string // Captures the host passed to RegistryLogin
	Releases             []Release
	Deleted              []Release
	Linted               []Release
	Unittested           []Release
	Templated            []Release
	Lists                map[ListKey]string
	Diffs                map[DiffKey]error
	Diffed               []Release
	FailOnUnexpectedDiff bool
	FailOnUnexpectedList bool
	Version              *semver.Version

	UpdateDepsCallbacks map[string]func(string) error

	DiffMutex     *sync.Mutex
	ChartsMutex   *sync.Mutex
	ReleasesMutex *sync.Mutex

	Helm3 bool
	Helm4 bool
}

func (*Helm) AddRepo

func (helm *Helm) AddRepo(name, repository, cafile, certfile, keyfile, username, password string, managed string, passCredentials, skipTLSVerify bool) error

func (*Helm) BuildDeps

func (helm *Helm) BuildDeps(name, chart string, flags ...string) error

func (*Helm) ChartExport

func (helm *Helm) ChartExport(chart string, path string) error

func (*Helm) ChartPull

func (helm *Helm) ChartPull(chart string, path string, flags ...string) error

func (*Helm) DecryptSecret

func (helm *Helm) DecryptSecret(context helmexec.HelmContext, name string, flags ...string) (string, error)

func (*Helm) DeleteRelease

func (helm *Helm) DeleteRelease(context helmexec.HelmContext, name string, flags ...string) error

func (*Helm) DiffRelease

func (helm *Helm) DiffRelease(context helmexec.HelmContext, name, chart, namespace string, suppressDiff bool, flags ...string) error

func (*Helm) Fetch

func (helm *Helm) Fetch(chart string, flags ...string) error

func (*Helm) GetVersion

func (helm *Helm) GetVersion() helmexec.Version

func (*Helm) IsHelm3

func (helm *Helm) IsHelm3() bool

func (*Helm) IsHelm4 added in v1.2.0

func (helm *Helm) IsHelm4() bool

func (*Helm) IsVersionAtLeast

func (helm *Helm) IsVersionAtLeast(versionStr string) bool

func (*Helm) Lint

func (helm *Helm) Lint(name, chart string, flags ...string) error

func (*Helm) List

func (helm *Helm) List(context helmexec.HelmContext, filter string, flags ...string) (string, error)

func (*Helm) RegistryLogin

func (helm *Helm) RegistryLogin(name, username, password, caFile, certFile, keyFile string, skipTLSVerify bool) error

func (*Helm) ReleaseStatus

func (helm *Helm) ReleaseStatus(context helmexec.HelmContext, release string, flags ...string) error

func (*Helm) SetDisableForceUpdate added in v0.153.0

func (helm *Helm) SetDisableForceUpdate(forceUpdate bool)

func (*Helm) SetEnableLiveOutput added in v0.146.0

func (helm *Helm) SetEnableLiveOutput(enableLiveOutput bool)

func (*Helm) SetExtraArgs

func (helm *Helm) SetExtraArgs(args ...string)

func (*Helm) SetHelmBinary

func (helm *Helm) SetHelmBinary(bin string)

func (*Helm) ShowChart added in v0.147.0

func (helm *Helm) ShowChart(chartPath string) (chart.Metadata, error)

func (*Helm) SkipSchemaValidation added in v0.169.2

func (helm *Helm) SkipSchemaValidation(skipSchemaValidation bool)

func (*Helm) SyncRelease

func (helm *Helm) SyncRelease(context helmexec.HelmContext, name, chart, namespace string, flags ...string) error

func (*Helm) TemplateRelease

func (helm *Helm) TemplateRelease(name, chart string, flags ...string) error

func (*Helm) TestRelease

func (helm *Helm) TestRelease(context helmexec.HelmContext, name string, flags ...string) error

func (*Helm) Unittest added in v1.3.0

func (helm *Helm) Unittest(name, chart string, flags ...string) error

func (*Helm) UpdateDeps

func (helm *Helm) UpdateDeps(chart string) error

func (*Helm) UpdateRepo

func (helm *Helm) UpdateRepo() error

type ListKey

type ListKey struct {
	Filter string
	Flags  string
}

func (ListKey) String

func (k ListKey) String() string

type Release

type Release struct {
	Name  string
	Flags []string
}

Jump to