policy

package
v0.152.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2023 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package policy provides a policy checker for the helmfile state.

Index

Constants

This section is empty.

Variables

var (
	EnvironmentsAndReleasesWithinSameYamlPartErr = errors.New("environments and releases cannot be defined within the same YAML part. Use --- to extract the environments into a dedicated part")
)

Functions

func Checker

func Checker(filePath string, helmState map[string]interface{}) (bool, error)

Checker is a policy checker for the helmfile state.

Types

This section is empty.

Jump to