Documentation
¶
Index ¶
- func CaptureStdout(f func()) (string, error)
- type HelmExec
- func (helm HelmExec) AddRepo(name, repository, cafile, certfile, keyfile, username, password string, ...) error
- func (helm HelmExec) BuildDeps(name, chart string, flags ...string) error
- func (helm HelmExec) ChartExport(chart string, path string) error
- func (helm HelmExec) ChartPull(chart string, path string, flags ...string) error
- func (helm HelmExec) DecryptSecret(context helmexec.HelmContext, name string, flags ...string) (string, error)
- func (helm HelmExec) DeleteRelease(context helmexec.HelmContext, name string, flags ...string) error
- func (helm HelmExec) DiffRelease(context helmexec.HelmContext, name, chart, namespace string, suppressDiff bool, ...) error
- func (helm HelmExec) Fetch(chart string, flags ...string) error
- func (helm HelmExec) GetVersion() helmexec.Version
- func (helm *HelmExec) IsHelm3() bool
- func (helm *HelmExec) IsHelm4() bool
- func (helm HelmExec) IsVersionAtLeast(versionStr string) bool
- func (helm HelmExec) Lint(name, chart string, flags ...string) error
- func (helm HelmExec) List(context helmexec.HelmContext, filter string, flags ...string) (string, error)
- func (helm HelmExec) RegistryLogin(name, username, password, caFile, certFile, keyFile string, skipTLSVerify bool) error
- func (helm HelmExec) ReleaseStatus(context helmexec.HelmContext, release string, flags ...string) error
- func (helm HelmExec) SetDisableForceUpdate(forceUpdate bool)
- func (helm HelmExec) SetEnableLiveOutput(enableLiveOutput bool)
- func (helm HelmExec) SetExtraArgs(args ...string)
- func (helm HelmExec) SetHelmBinary(bin string)
- func (helm HelmExec) ShowChart(chartPath string) (chart.Metadata, error)
- func (helm HelmExec) SyncRelease(context helmexec.HelmContext, name, chart, namespace string, flags ...string) error
- func (helm HelmExec) TemplateRelease(name, chart string, flags ...string) error
- func (helm HelmExec) TestRelease(context helmexec.HelmContext, name string, flags ...string) error
- func (helm HelmExec) UpdateDeps(chart string) error
- func (helm HelmExec) UpdateRepo() error
- type VersionHelmExec
- func (helm VersionHelmExec) AddRepo(name, repository, cafile, certfile, keyfile, username, password string, ...) error
- func (helm VersionHelmExec) BuildDeps(name, chart string, flags ...string) error
- func (helm VersionHelmExec) ChartExport(chart string, path string) error
- func (helm VersionHelmExec) ChartPull(chart string, path string, flags ...string) error
- func (helm VersionHelmExec) DecryptSecret(context helmexec.HelmContext, name string, flags ...string) (string, error)
- func (helm VersionHelmExec) DeleteRelease(context helmexec.HelmContext, name string, flags ...string) error
- func (helm VersionHelmExec) DiffRelease(context helmexec.HelmContext, name, chart, namespace string, suppressDiff bool, ...) error
- func (helm VersionHelmExec) Fetch(chart string, flags ...string) error
- func (helm VersionHelmExec) GetVersion() helmexec.Version
- func (helm *VersionHelmExec) IsHelm3() bool
- func (helm *VersionHelmExec) IsHelm4() bool
- func (helm *VersionHelmExec) IsVersionAtLeast(ver string) bool
- func (helm VersionHelmExec) Lint(name, chart string, flags ...string) error
- func (helm VersionHelmExec) List(context helmexec.HelmContext, filter string, flags ...string) (string, error)
- func (helm VersionHelmExec) RegistryLogin(name, username, password, caFile, certFile, keyFile string, skipTLSVerify bool) error
- func (helm VersionHelmExec) ReleaseStatus(context helmexec.HelmContext, release string, flags ...string) error
- func (helm VersionHelmExec) SetDisableForceUpdate(forceUpdate bool)
- func (helm VersionHelmExec) SetEnableLiveOutput(enableLiveOutput bool)
- func (helm VersionHelmExec) SetExtraArgs(args ...string)
- func (helm VersionHelmExec) SetHelmBinary(bin string)
- func (helm VersionHelmExec) ShowChart(chartPath string) (chart.Metadata, error)
- func (helm VersionHelmExec) SyncRelease(context helmexec.HelmContext, name, chart, namespace string, flags ...string) error
- func (helm VersionHelmExec) TemplateRelease(name, chart string, flags ...string) error
- func (helm VersionHelmExec) TestRelease(context helmexec.HelmContext, name string, flags ...string) error
- func (helm VersionHelmExec) UpdateDeps(chart string) error
- func (helm VersionHelmExec) UpdateRepo() error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CaptureStdout ¶
CaptureStdout is a helper function to capture stdout.
Types ¶
type HelmExec ¶ added in v1.2.0
type HelmExec struct {
// contains filtered or unexported fields
}
func NewHelmExec ¶ added in v1.2.0
func (HelmExec) ChartExport ¶ added in v1.2.0
func (HelmExec) DecryptSecret ¶ added in v1.2.0
func (HelmExec) DeleteRelease ¶ added in v1.2.0
func (helm HelmExec) DeleteRelease(context helmexec.HelmContext, name string, flags ...string) error
func (HelmExec) DiffRelease ¶ added in v1.2.0
func (HelmExec) GetVersion ¶ added in v1.2.0
func (HelmExec) IsVersionAtLeast ¶ added in v1.2.0
func (HelmExec) RegistryLogin ¶ added in v1.2.0
func (HelmExec) ReleaseStatus ¶ added in v1.2.0
func (helm HelmExec) ReleaseStatus(context helmexec.HelmContext, release string, flags ...string) error
func (HelmExec) SetDisableForceUpdate ¶ added in v1.2.0
func (helm HelmExec) SetDisableForceUpdate(forceUpdate bool)
func (HelmExec) SetEnableLiveOutput ¶ added in v1.2.0
func (helm HelmExec) SetEnableLiveOutput(enableLiveOutput bool)
func (HelmExec) SetExtraArgs ¶ added in v1.2.0
func (helm HelmExec) SetExtraArgs(args ...string)
func (HelmExec) SetHelmBinary ¶ added in v1.2.0
func (helm HelmExec) SetHelmBinary(bin string)
func (HelmExec) SyncRelease ¶ added in v1.2.0
func (helm HelmExec) SyncRelease(context helmexec.HelmContext, name, chart, namespace string, flags ...string) error
func (HelmExec) TemplateRelease ¶ added in v1.2.0
func (HelmExec) TestRelease ¶ added in v1.2.0
func (helm HelmExec) TestRelease(context helmexec.HelmContext, name string, flags ...string) error
func (HelmExec) UpdateDeps ¶ added in v1.2.0
func (HelmExec) UpdateRepo ¶ added in v1.2.0
func (helm HelmExec) UpdateRepo() error
type VersionHelmExec ¶ added in v0.154.0
type VersionHelmExec struct {
// contains filtered or unexported fields
}
func NewVersionHelmExec ¶ added in v0.154.0
func NewVersionHelmExec(version string) *VersionHelmExec
func (VersionHelmExec) ChartExport ¶ added in v0.154.0
func (VersionHelmExec) DecryptSecret ¶ added in v0.154.0
func (VersionHelmExec) DeleteRelease ¶ added in v0.154.0
func (helm VersionHelmExec) DeleteRelease(context helmexec.HelmContext, name string, flags ...string) error
func (VersionHelmExec) DiffRelease ¶ added in v0.154.0
func (VersionHelmExec) GetVersion ¶ added in v0.154.0
func (*VersionHelmExec) IsHelm3 ¶ added in v0.154.0
func (helm *VersionHelmExec) IsHelm3() bool
func (*VersionHelmExec) IsHelm4 ¶ added in v1.2.0
func (helm *VersionHelmExec) IsHelm4() bool
func (*VersionHelmExec) IsVersionAtLeast ¶ added in v0.154.0
func (helm *VersionHelmExec) IsVersionAtLeast(ver string) bool
func (VersionHelmExec) RegistryLogin ¶ added in v0.154.0
func (VersionHelmExec) ReleaseStatus ¶ added in v0.154.0
func (helm VersionHelmExec) ReleaseStatus(context helmexec.HelmContext, release string, flags ...string) error
func (VersionHelmExec) SetDisableForceUpdate ¶ added in v0.154.0
func (helm VersionHelmExec) SetDisableForceUpdate(forceUpdate bool)
func (VersionHelmExec) SetEnableLiveOutput ¶ added in v0.154.0
func (helm VersionHelmExec) SetEnableLiveOutput(enableLiveOutput bool)
func (VersionHelmExec) SetExtraArgs ¶ added in v0.154.0
func (helm VersionHelmExec) SetExtraArgs(args ...string)
func (VersionHelmExec) SetHelmBinary ¶ added in v0.154.0
func (helm VersionHelmExec) SetHelmBinary(bin string)
func (VersionHelmExec) SyncRelease ¶ added in v0.154.0
func (helm VersionHelmExec) SyncRelease(context helmexec.HelmContext, name, chart, namespace string, flags ...string) error
func (VersionHelmExec) TemplateRelease ¶ added in v0.154.0
func (VersionHelmExec) TestRelease ¶ added in v0.154.0
func (helm VersionHelmExec) TestRelease(context helmexec.HelmContext, name string, flags ...string) error
func (VersionHelmExec) UpdateDeps ¶ added in v0.154.0
func (VersionHelmExec) UpdateRepo ¶ added in v0.154.0
func (helm VersionHelmExec) UpdateRepo() error
Click to show internal directories.
Click to hide internal directories.