Documentation
¶
Index ¶
- func IsHelm4Enabled() bool
- type Affected
- type DiffKey
- type Helm
- func (helm *Helm) AddRepo(name, repository, cafile, certfile, keyfile, username, password string, ...) error
- func (helm *Helm) BuildDeps(name, chart string, flags ...string) error
- func (helm *Helm) ChartExport(chart string, path string) error
- func (helm *Helm) ChartPull(chart string, path string, flags ...string) error
- func (helm *Helm) DecryptSecret(context helmexec.HelmContext, name string, flags ...string) (string, error)
- func (helm *Helm) DeleteRelease(context helmexec.HelmContext, name string, flags ...string) error
- func (helm *Helm) DiffRelease(context helmexec.HelmContext, name, chart, namespace string, suppressDiff bool, ...) error
- func (helm *Helm) Fetch(chart string, flags ...string) error
- func (helm *Helm) GetVersion() helmexec.Version
- func (helm *Helm) IsHelm3() bool
- func (helm *Helm) IsHelm4() bool
- func (helm *Helm) IsVersionAtLeast(versionStr string) bool
- func (helm *Helm) Lint(name, chart string, flags ...string) error
- func (helm *Helm) List(context helmexec.HelmContext, filter string, flags ...string) (string, error)
- func (helm *Helm) RegistryLogin(name, username, password, caFile, certFile, keyFile string, skipTLSVerify bool) error
- func (helm *Helm) ReleaseStatus(context helmexec.HelmContext, release string, flags ...string) error
- func (helm *Helm) SetDisableForceUpdate(forceUpdate bool)
- func (helm *Helm) SetEnableLiveOutput(enableLiveOutput bool)
- func (helm *Helm) SetExtraArgs(args ...string)
- func (helm *Helm) SetHelmBinary(bin string)
- func (helm *Helm) ShowChart(chartPath string) (chart.Metadata, error)
- func (helm *Helm) SkipSchemaValidation(skipSchemaValidation bool)
- func (helm *Helm) SyncRelease(context helmexec.HelmContext, name, chart, namespace string, flags ...string) error
- func (helm *Helm) TemplateRelease(name, chart string, flags ...string) error
- func (helm *Helm) TestRelease(context helmexec.HelmContext, name string, flags ...string) error
- func (helm *Helm) Unittest(name, chart string, flags ...string) error
- func (helm *Helm) UpdateDeps(chart string) error
- func (helm *Helm) UpdateRepo() error
- type ListKey
- type Release
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsHelm4Enabled ¶ added in v1.2.0
func IsHelm4Enabled() bool
IsHelm4Enabled detects the installed Helm version by executing the helm binary. It returns true if Helm 4.x is installed, false for Helm 3.x or earlier. Falls back to environment variable HELMFILE_HELM4 if helm binary is not available.
Types ¶
type Helm ¶
type Helm struct {
Charts []string
Repo []string
RegistryLoginHost string // Captures the host passed to RegistryLogin
Releases []Release
Deleted []Release
Linted []Release
Unittested []Release
Templated []Release
Lists map[ListKey]string
Diffs map[DiffKey]error
Diffed []Release
FailOnUnexpectedDiff bool
FailOnUnexpectedList bool
Version *semver.Version
UpdateDepsCallbacks map[string]func(string) error
DiffMutex *sync.Mutex
ChartsMutex *sync.Mutex
ReleasesMutex *sync.Mutex
Helm3 bool
Helm4 bool
}
func (*Helm) DecryptSecret ¶
func (*Helm) DeleteRelease ¶
func (*Helm) DiffRelease ¶
func (*Helm) GetVersion ¶
func (*Helm) IsVersionAtLeast ¶
func (*Helm) RegistryLogin ¶
func (*Helm) ReleaseStatus ¶
func (*Helm) SetDisableForceUpdate ¶ added in v0.153.0
func (*Helm) SetEnableLiveOutput ¶ added in v0.146.0
func (*Helm) SetExtraArgs ¶
func (*Helm) SetHelmBinary ¶
func (*Helm) SkipSchemaValidation ¶ added in v0.169.2
func (*Helm) SyncRelease ¶
func (*Helm) TemplateRelease ¶
func (*Helm) TestRelease ¶
func (*Helm) UpdateDeps ¶
func (*Helm) UpdateRepo ¶
Click to show internal directories.
Click to hide internal directories.